<?php
if ( ! function_exists( 'page_type_test' ) ) :
	/**
	 * Test the page type
	 *
	 * @since 1.0
	 */
	function page_type_test(){

		$current = "default";
		
		if ( is_home() ){
			$current = "home";
		}
		if ( is_post_type_archive() ){
			$current = "archive";
		}
		if ( is_single() ) {
			$current = "single";
		}
		return $current;

	}
endif;

if ( ! function_exists( 'post_date' ) ) :
	/**
	 * Generate post date + byline display
	 *
	 * @since 1.0
	 */
	function post_date() {
		echo '<span class="posted-on"><i class="icon-calendar"></i>&nbsp;' . time_link() . '</span><span class="byline"></span>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'post_author' ) ) :
	/**
	 * Generate post date + byline display
	 *
	 * @since 1.0
	 */
	function post_author() {
		echo 'by <span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>';
	}
endif;

if ( ! function_exists( 'search_bar' ) ) :
	/**
	 * Generate post date + byline display
	 *
	 * @since 1.0
	 */
	function search_bar() {
		include(locate_template('components/utility/search.php'));
	}
endif;

if ( ! function_exists( 'time_link' ) ) :
	/**
	 * Generate post time display
	 *
	 * @since 1.0
	 */
	function time_link() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		$time_string = get_the_date();
		return '<span class="screen-reader-text">' . _x( 'Posted on', 'post date', '' ) . '</span> <a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';
	}
endif;

if ( ! function_exists( 'post_meta_categories' ) ) :
	/**
	 * Generate post categories display
	 *
	 * @since 1.0
	 */
	function post_meta_categories() {
		$separate_meta = __( ', ', '' );
		$categories_list = get_the_category_list($separate_meta);
		if ( $categories_list ) {
			echo '<div class="post-categories col-12">';
			echo '<span class="cat-links"><span class="screen-reader-text">' . __( 'Categories') . '</span><i class="icon-folder-open"></i>&nbsp;' . $categories_list . '</span>';
			echo '</div>';
		}
	}
endif;

if ( ! function_exists( 'post_meta_tags' ) ) :
	/**
	 * Generate post tags display
	 *
	 * @since 1.0
	 */
	function post_meta_tags() {
		$separate_meta = __( ', ', '' );
		$tags_list = get_the_tag_list( '', $separate_meta );
		if ( $tags_list ) {
			echo '<div class="post-tags col-12">';
			echo '<span class="tags-links"><span class="screen-reader-text">' . __( 'Tags', '' ) . '</span><i class="icon-price-tag"></i>&nbsp;' . $tags_list . '</span>';
		}
	}
endif;

if ( ! function_exists( 'build_wrapper' ) ) :
	/**
	 * Generate Build the wrapper for the ACF layouts system
	 *
	 * @since 1.0
	 */
	function build_wrapper($classes,$id,$inline_styles){

		echo '<div';

		if ( $id ){
			echo ' id="'.$id.'"';
		}

		if ( $classes ){
			echo ' class="';

			$classes_last = end($classes);
			foreach ( $classes as $class):
				echo $class;
				if ( $class !== $classes_last ){
					echo ' ';
				}
			endforeach;

			echo '"';
		}

		if ( $inline_styles ){
			echo ' style="';
			foreach ( $inline_styles as $inline_style):
				echo $inline_style;
			endforeach;
			echo '"';
		}
		
		echo '>';

	}
endif;

if ( ! function_exists( 'read_more' ) ) :
	/**
	 * Generate post read more display
	 *
	 * @since 1.0
	 */
	function read_more() {
		$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', '' ), get_the_title( get_the_ID() ) )
		);
		return ' &hellip; ' . $link;
	}
	add_filter( 'excerpt_more', 'read_more' );
endif;

if ( ! function_exists( 'print_var_name' ) ) :
	/**
	 * Print out a variable's name as a string
	 *
	 * @since 1.0
	 */
	function print_var_name($var) {
	    foreach($GLOBALS as $var_name => $value) {
	        if ($value === $var) {
	            return $var_name;
	        }
	    }

	    return false;
	}
endif;

if ( ! function_exists( 'make_grid' ) ) :
	/**
	 * Build the necessary css classes for a BS4 grid unit
	 *
	 * @since 1.0
	 */
	function make_grid( $xs, $sm, $md, $lg, $xl ){
		$cols = [ $xs, $sm, $md, $lg, $xl ];
		$col_classes = [];

		foreach ( $cols as $col ):

			switch ( $col ){

		        case "hidden":
		        	array_push( $col_classes, 'hidden-' . print_var_name( $col ) );
		        	break;

		        case "col":
		        	array_push( $col_classes, 'col' . print_var_name( $col ) );
		        	break;

		        default:
		        	array_push( $col_classes, 'col-' . print_var_name( $col ) . '-' . $col );
		        	break;

			}

		endforeach;

		$col_classes_display = implode( " ", $col_classes );
		return $col_classes_display;
	}
endif;

if ( ! function_exists( 'make_acf_layout' ) ) :
	/**
	 * Shorthand function to load an ACF flexible content layout with wrappers
	 *
	 * @since 1.0
	 */
	function make_acf_layout($name="",$file,$wrapped=true){
		
		$layout_name = $name;

		if ( $wrapped === true ){
			 include(locate_template('components/layout/wrapper/open.php'));
		}

		include(locate_template($file));

		if ( $wrapped === true ){
			include(locate_template('components/layout/wrapper/close.php'));
		}

	}
endif;

class New_Menu_Walker extends Walker_Nav_Menu{

        function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {

                if ( !$element )
                        return;

                $id_field = $this->db_fields['id'];

                //display this element
                if ( is_array( $args[0] ) )
                        $args[0]['has_children'] = ! empty( $children_elements[$element->$id_field] );

                //Adds the 'parent' class to the current item if it has children               
                if( ! empty( $children_elements[$element->$id_field] ) ) {
                        array_push($element->classes,'parent');
                        $element->title .= ' <i class="icon-arrow-down sub-menu-karet"></i>';
                }

                $cb_args = array_merge( array(&$output, $element, $depth), $args);

                call_user_func_array(array(&$this, 'start_el'), $cb_args);

                $id = $element->$id_field;

                // descend only when the depth is right and there are childrens for this element
                if ( ($max_depth == 0 || $max_depth > $depth+1 ) && isset( $children_elements[$id]) ) {

                        foreach( $children_elements[ $id ] as $child ){

                                if ( !isset($newlevel) ) {
                                        $newlevel = true;
                                        //start the child delimiter
                                        $cb_args = array_merge( array(&$output, $depth), $args);
                                        call_user_func_array(array(&$this, 'start_lvl'), $cb_args);
                                }
                                $this->display_element( $child, $children_elements, $max_depth, $depth + 1, $args, $output );
                        }
                        unset( $children_elements[ $id ] );
                }

                if ( isset($newlevel) && $newlevel ){
                        //end the child delimiter
                        $cb_args = array_merge( array(&$output, $depth), $args);
                        call_user_func_array(array(&$this, 'end_lvl'), $cb_args);
                }

                //end this element
                $cb_args = array_merge( array(&$output, $element, $depth), $args);
                call_user_func_array(array(&$this, 'end_el'), $cb_args);
        }
}